@@ -281,30 +281,30 @@ while 1:
   sleeptime = expire_interval
   # delete any orphaned views, which shouldn't exist unless there was a restart or crash
   mysql(c, """DELETE FROM view WHERE heartbeat < DATE_ADD(NOW(), INTERVAL -1 DAY)""")
-  
+
   # Anonymous sessions
   if ANONYMOUS_SESSIONS:
     anon_arr = mysql(c, """
              SELECT session.sessnum, appname
              FROM session LEFT JOIN view ON session.sessnum = view.sessnum
-             WHERE session.username = 'anonymous' 
+             WHERE session.username = 'anonymous'
              AND viewid IS NULL""")
     for sessnum, appname in anon_arr:
       session = int(sessnum)
       terminate(sessnum, 'anonymous', appname)
       time.sleep(1) # Do not kill things off too quickly.
       sleeptime -= 1
-  
+
   # Regular sessions
   # Find sessions that have been accessed more than "timeout" seconds ago
   # and that have no views, and that could expire during our next sleep (expire_interval)
   # skew: keep track of sleep time between each expired session
-  skew = 0 
+  skew = 0
   arr = mysql(c, """
     SELECT session.sessnum, session.username, appname,
       timeout - TIMESTAMPDIFF(SECOND, accesstime, NOW()) AS remaining
     FROM session LEFT JOIN view ON session.sessnum = view.sessnum
-    WHERE viewid IS NULL 
+    WHERE viewid IS NULL
     AND exechost != 'submit'
     AND timeout - TIMESTAMPDIFF(SECOND, accesstime, NOW()) < %d
     ORDER BY remaining""" % (expire_interval))
@@ -322,8 +322,9 @@ while 1:
       continue
     # heartbeat is considered "stale" after 24 hours
     # remaining = heartbeat - NOW() + 86400
+    # In submit version >= 2.7.x job.active=2 jobs should be ignored when considering the heartbeat update
     job_arr = mysql(c, """SELECT 86400-TIMESTAMPDIFF(SECOND, heartbeat, NOW()) AS remaining
-      FROM job WHERE sessnum = "%s"
+      FROM job WHERE sessnum = "%s" AND active !=2
       AND 86400-TIMESTAMPDIFF(SECOND, heartbeat, NOW()) > 0""" % sessnum)
     if job_arr:
       # Find the greatest reason this session should stay alive
@@ -334,11 +335,11 @@ while 1:
       if max_remaining > sleeptime:
         continue
 
-    # How long should someone have to check the results of a simulation?  
-    # people have 24 hours to check results after the end of the last job.  
-    # If a job started at 9AM took 12 hours to run then a user would have until 9PM 
-    # the next day to check results.  It's always possible to check the results before 
-    # the session ends. 
+    # How long should someone have to check the results of a simulation?
+    # people have 24 hours to check results after the end of the last job.
+    # If a job started at 9AM took 12 hours to run then a user would have until 9PM
+    # the next day to check results.  It's always possible to check the results before
+    # the session ends.
     # if any joblog entry is for a job that ended less than a day ago, pass
     # remaining = start + walltime - NOW() + 86400
     # walltime > TIME_TO_SEC(start) is because it's possible for walltime to be calculated from epoch
@@ -362,7 +363,7 @@ while 1:
       time.sleep(1) # Do not kill things off too quickly.
       skew += 1
     elif max_remaining < sleeptime:
-      sleeptime = max_remaining      
+      sleeptime = max_remaining
 
   sleeptime -= skew
   if (sleeptime > 0):
